shouldReload method

  1. @override
bool shouldReload(
  1. covariant LocalizationsPlusDelegate old
)
override

Returns true if the resources for this delegate should be loaded again by calling the load method.

This method is called whenever its Translations widget is rebuilt. If it returns true then dependent widgets will be rebuilt after load has completed.

Implementation

@override
bool shouldReload(LocalizationsPlusDelegate old) => true;