translations library
Classes
- Translations
-
A type localized resource class which should init
supportedbefore use.
Extensions
- TranslationsExtension on BuildContext
- Extension to easily access translations from the BuildContext
Typedefs
- I18NCallback = String Function(String key, [dynamic args])
- A type definition for the translation callback function, which takes a key and optional arguments and returns a localized string